require 'httparty'

module TorgiGov
  class LoadNotification
    include HTTParty
    base_uri 'torgi.gov.ru'

    def initialize(args)
      @number = args[:number]
    end

    def call
      request = self.class.get("/opendata/notification/#{@number}")
      @body = Nokogiri.XML(request.body)
      parse
    end

    private

    def parse
      raise NotImplementedError
    end

    def number
      @body.css('notification bidNumber').text
    end

    def organization
      {
        type:     @body.css('notification bidOrganization').text,
        id:       @body.css('notification bidOrgKind').text,
        fullName: @body.css('notification fullName').text,
        headOrg:  @body.css('notification headOrg').text,
        inn:      @body.css('notification inn').text,
      }
    end

    def common
      {
        bid_kind:        bid_kind,
        bid_form:        bid_form,
        lotNum:          @body.css('notification common lotNum').text,
        published:       @body.css('notification common published').text,
        lastChanged:     @body.css('notification common lastChanged').text,
        notificationUrl: @body.css('notification common notificationUrl').text,
        bidAuctionDate:  @body.css('notification common bidAuctionDate').text,
        summationDate:   @body.css('notification common summationDate').text,
      }
    end

    def bid_kind
      {
        id:    @body.css('notification common bidKind id').text,
        name:  @body.css('notification common bidKind name').text,
      }
    end

    def bid_form
      {
        id:   @body.css('notification common bidForm id').text,
        name: @body.css('notification common bidForm name').text
      }
    end

    def docs
      @body.css('notification documents doc').collect do |doc|
        {
          docType: doc.css('docType').text,
          created: doc.css('created').text,
          docUrl:  doc.css('docUrl').text
        }
      end
    end
  end
end